버드아이에 대해
==========================

Birdseye는 Alex Hall이 만든 멋진 Python 디버거로, 프로그램이 실행될 때 표현식의 값들을 기록하고
프로그램이 완료된 후 이 값들을 탐색 할 수 있습니다. 더 많은 정보는
`https://birdseye.readthedocs.io <https://birdseye.readthedocs.io>`_ 에서 확인하세요.

Birdseye는 기본적으로 설치되지 않으며 *도구 → 플러그인 관리...*를 통해 간단하게 설치할 수 있습니다.
``birdseye`` 라는 이름의 패키지를 설치하면 됩니다.

Birdseye는`Thonny의 내장 디버거 <debuggers.rst>`_ 와는 다르게 작동합니다.
*실행 → 현재 스크립트 디버그(Birdseye)*로 프로그램을 실행하면 실행 시간이 평소보다 약간 더 걸립니다.
그러나 *Run current script*로 실행 한 것처럼 프로그램이 실행됩니다.
다시 말해, 브레이크 포인트가 무시되고 프로그램을 단계별로 실행할 수 없습니다.
그러나 프로그램의 실행이 완료되면 Thonny는 웹 페이지 (Birdseye에서 제공하는 로컬 서버에서 제공)
를 열어 실행 프로세스를 자세히 살펴보고 최종 결과가
어떻게 중간값으로 구성되는지를 확인 할 수 있습니다.

주의! Thonny에서 Birdseye를 사용할 때``birdseye.eye``를 가져오거나
함수를 데코레이팅할 필요가 없습니다. Thonny는 모든 기능에 대한 정보를 기록하도록
Birdseye를 실행합니다.

로컬 서버는 기본적으로 포트 7777을 사용합니다. 만약 다른 응용 프로그램에서 사용하는 경우 다른 포트
(도구 → 옵션 → 실행 & 디버그)를 설정하고 Thonny를 다시 시작하면 됩니다.
